@@ -2,6 +2,7 @@ import PyAuthGG
 
 import requests
 import json
+import bs4
 
 import subprocess
 import getpass
@@ -14,6 +15,16 @@ class Application():
         self.URL = "https://api.auth.gg/v1/"
         self.HEADERS = PyAuthGG.HEADERS
 
+    def Status(self):
+        r = requests.get("https://authgg.statuspage.io/")
+        soup = bs4.BeautifulSoup(r.text, 'html.parser')
+        SpanElements = soup.find_all("span", class_="component-status")
+        StatusList = []
+        for x in SpanElements:
+            StatusList.append(x.text.replace("\n", "").replace(" ", ""))
+
+        return {"Backend/API" : StatusList[0], "Frontend" : StatusList[1], "S3 Storage" : StatusList[2]}
+
     def Info(self):
         DATA = {"type" : "info", "aid" : self.AID, "apikey" : self.API, "secret" : self.SECRET}
         r = requests.post(self.URL, data=DATA, headers=self.HEADERS).json()
@@ -34,7 +45,6 @@ class Application():
         return r
 
     def Extend(self, LICENSE : str, USER : str, PASS : str):
-        HWID = str(subprocess.check_output('wmic csproduct get uuid')).split('\\r\\n')[1].strip('\\r').strip()
         DATA = {"type" : "extend", "aid" : self.AID, "apikey" : self.API, "secret" : self.SECRET, "username" : USER, "password" : PASS, "license" : LICENSE}
 
         r = requests.post(self.URL, data=DATA, headers=self.HEADERS).json()
@@ -47,7 +57,6 @@ class Application():
         return r
 
     def ChangePassword(self, USER : str, PASS : str, NEWPASS : str):
-        HWID = str(subprocess.check_output('wmic csproduct get uuid')).split('\\r\\n')[1].strip('\\r').strip()
         DATA = {"type" : "changepw", "aid" : self.AID, "apikey" : self.API, "secret" : self.SECRET, "username" : USER, "password" : PASS, "newpassword" : NEWPASS}
 
         r = requests.post(self.URL, data=DATA, headers=self.HEADERS).json()
